pub struct ImportAttributes {
pub ignore: bool,
pub optional: bool,
pub export_names: Option<SmallVec<[RcStr; 1]>>,
pub chunking_type: Option<SpecifiedChunkingType>,
}Expand description
Represents a collection of webpack-style “magic comments” that override import behaviors.
Fields
ignore: boolShould we ignore this import expression when bundling? If so, the import expression will be left as-is in Turbopack’s output.
This is set by using either a webpackIgnore or turbopackIgnore comment.
Example:
const a = import(/* webpackIgnore: true */ "a");
const b = import(/* turbopackIgnore: true */ "b");optional: boolShould resolution errors be suppressed? If so, resolution errors will be completely ignored (no error or warning emitted at build time).
This is set by using a turbopackOptional comment.
Example:
const a = import(/* turbopackOptional: true */ "a");export_names: Option<SmallVec<[RcStr; 1]>>Which exports are used from a dynamic import. When set, enables tree-shaking for the dynamically imported module by only including the specified exports.
This is set by using either a webpackExports or turbopackExports comment.
None means no directive was found (all exports assumed used).
Some([]) means empty list (only side effects).
Some([name, ...]) means specific named exports are used.
Example:
const { a } = await import(/* webpackExports: ["a"] */ "module");
const { b } = await import(/* turbopackExports: "b" */ "module");chunking_type: Option<SpecifiedChunkingType>Whether to use a specific chunking type for this import.
This is set by using a or turbopackChunkingType comment.
Example:
const a = require(/* turbopackChunkingType: parallel */ "a");Implementations