pub fn parse_require_context(
args: &[JsValue<'_>],
) -> Result<RequireContextOptions>Expand description
Parse the arguments passed to a require.context invocation, validate them and convert them to the appropriate rust values.
pub fn parse_require_context(
args: &[JsValue<'_>],
) -> Result<RequireContextOptions>Parse the arguments passed to a require.context invocation, validate them and convert them to the appropriate rust values.