compute_chunk_list_version

Function compute_chunk_list_version 

pub async fn compute_chunk_list_version(
    chunks_contents: &FxIndexMap<String, ResolvedVc<Box<dyn VersionedContent>>>,
) -> Result<Vc<ChunkListVersion>>
Computes a ChunkListVersion from a map of chunk paths to their VersionedContent.

Chunks that implement MergeableVersionedContent are grouped by their merger and their versions are merged. Other chunks are tracked by path.