chunk_item_content_with_code_from

Function chunk_item_content_with_code_from 

pub fn chunk_item_content_with_code_from(
    module: Vc<Box<dyn EcmascriptChunkPlaceable>>,
    code_source: Vc<Box<dyn EcmascriptChunkPlaceable>>,
    chunking_context: Vc<Box<dyn ChunkingContext>>,
    async_module_info: Option<Vc<AsyncModuleInfo>>,
) -> Vc<EcmascriptChunkItemContent>
Generate the code of a processed virtual module under the identity of the module in the graph. The code source supplies its parsed program, references, exports and async behavior; the graph module supplies the identity for export usage and other code generation.