pub struct ManifestLoaderModule {
pub manifest: ResolvedVc<ManifestAsyncModule>,
}Expand description
The manifest loader module is shipped in the same chunk that uses the dynamic
import() expression.
Its responsibility is to load the manifest chunk from the server. The dynamic import has been rewritten to import this manifest loader module, which will load the manifest chunk from the server, which will load all the chunks needed by the dynamic import. Finally, we’ll be able to import the module we’re trying to dynamically import.
Splitting the dynamic import into a quickly generate-able manifest loader module and a slow-to-generate manifest chunk allows for faster incremental compilation. The traversal won’t be performed until the dynamic import is actually reached, instead of eagerly as part of the chunk that the dynamic import appears in.
Fields
manifest: ResolvedVc<ManifestAsyncModule>Implementations
Sourceimpl ManifestLoaderModule
impl ManifestLoaderModule
pub fn new(manifest: Vc<ManifestAsyncModule>) -> Vc<Self>
pub fn chunks_data(self: Vc<Self>) -> Vc<ChunksData>
pub fn asset_ident_for(module: Vc<Box<dyn ChunkableModule>>) -> Vc<AssetIdent>
Sourceimpl ManifestLoaderModule
impl ManifestLoaderModule
pub fn content_ident(self: Vc<Self>) -> Vc<AssetIdent>