pub struct EsmExports {
pub exports: FrozenMap<RcStr, EsmExport>,
pub star_exports: Vec<ResolvedVc<Box<dyn ModuleReference>>>,
pub mangle_export_names: bool,
}Fields
exports: FrozenMap<RcStr, EsmExport>Explicit exports
star_exports: Vec<ResolvedVc<Box<dyn ModuleReference>>>Unexpanded export * from ... statements (expanded in expand_star_exports)
mangle_export_names: boolWhether the keys these exports are emitted under may be shortened. Carried with the exports
so a module deriving its exports from another (facade, locals, part, rename) inherits it.
mangle::mangled_export_names decides whether they actually are.
Implementations
Sourceimpl EsmExports
impl EsmExports
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
[ResolvedVc][turbo_tasks::ResolvedVc].
Cell is selected based on the value type and call order of cell.
Sourceimpl EsmExports
impl EsmExports
Sourcepub fn reexport_including_default(
module_reference: Vc<Box<dyn ModuleReference>>,
) -> Vc<EcmascriptExports>
pub fn reexport_including_default( module_reference: Vc<Box<dyn ModuleReference>>, ) -> Vc<EcmascriptExports>
Creates an EsmExports that re-exports all exports from another module. This is useful for wrapper modules that simply forward all exports.
The resulting exports will have:
- A default export binding to the module’s default
- A star export that re-exports all named exports
pub fn expand_exports( self: Vc<Self>, export_usage_info: Vc<ModuleExportUsageInfo>, ) -> Vc<ExpandedExports>
Sourceimpl EsmExports
impl EsmExports
pub async fn code_generation( self: Vc<Self>, chunking_context: Vc<Box<dyn ChunkingContext>>, scope_hoisting_context: ScopeHoistingContext<'_>, eval_context: &EvalContext, module: ResolvedVc<Box<dyn EcmascriptChunkPlaceable>>, ) -> Result<CodeGeneration>