pub struct PresetEnvConfig {
pub mode: Option<RcStr>,
pub core_js: Option<RcStr>,
pub skip: Option<Vec<RcStr>>,
pub include: Option<Vec<RcStr>>,
pub exclude: Option<Vec<RcStr>>,
pub shipped_proposals: Option<bool>,
pub force_all_transforms: Option<bool>,
pub debug: Option<bool>,
pub loose: Option<bool>,
}Expand description
Additional options for SWC’s preset-env, beyond the browserslist-derived
targets that are already provided by the Environment.
These correspond to the fields documented at https://swc.rs/docs/configuration/supported-browsers.
Fields
mode: Option<RcStr>Polyfill injection mode ("usage" or "entry"), matching Babel’s
useBuiltIns.
core_js: Option<RcStr>The core-js version string (e.g. "3.38").
skip: Option<Vec<RcStr>>Core-js modules or SWC transform passes to skip.
include: Option<Vec<RcStr>>Core-js modules or SWC transform passes to always include.
exclude: Option<Vec<RcStr>>Core-js modules or SWC transform passes to always exclude.
shipped_proposals: Option<bool>Enable shipped TC39 proposals.
force_all_transforms: Option<bool>Force all transforms regardless of targets.
debug: Option<bool>Enable debug output.
loose: Option<bool>Enable loose mode for transforms.
Implementations
Sourceimpl PresetEnvConfig
impl PresetEnvConfig
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
[ResolvedVc][turbo_tasks::ResolvedVc].
Cell is selected based on the value type and call order of cell.