pub struct SideEffectsModule {
pub module: ResolvedVc<EcmascriptModuleAsset>,
pub part: ModulePart,
pub resolved_as: ResolvedVc<Box<dyn EcmascriptChunkPlaceable>>,
pub side_effects: Vec<ResolvedVc<Box<dyn EcmascriptChunkPlaceable>>>,
}Fields
module: ResolvedVc<EcmascriptModuleAsset>Original module
part: ModulePartThe part of the original module that is the binding
resolved_as: ResolvedVc<Box<dyn EcmascriptChunkPlaceable>>The module that is the binding
side_effects: Vec<ResolvedVc<Box<dyn EcmascriptChunkPlaceable>>>Side effects from the original module to the binding.
Implementations
Sourceimpl SideEffectsModule
impl SideEffectsModule
pub fn new( module: Vc<EcmascriptModuleAsset>, part: ModulePart, resolved_as: Vc<Box<dyn EcmascriptChunkPlaceable>>, side_effects: Vec<Vc<Box<dyn EcmascriptChunkPlaceable>>>, ) -> Vc<Self>