pub fn module_value_to_well_known_object<'a>(
module_value: &ModuleValue,
) -> Option<JsValue<'a>>Expand description
Converts a module value (ie an import) to a well known object, which we specifically handle.
pub fn module_value_to_well_known_object<'a>(
module_value: &ModuleValue,
) -> Option<JsValue<'a>>Converts a module value (ie an import) to a well known object, which we specifically handle.