pub enum EcmascriptExports {
EsmExports(ResolvedVc<EsmExports>),
DynamicNamespace,
CommonJs,
EmptyCommonJs,
Value,
Unknown,
None,
}Variants
EsmExports(ResolvedVc<EsmExports>)
A module using ESM exports.
DynamicNamespace
A module using __turbopack_export_namespace__, used by custom module types.
CommonJs
A module using CommonJS exports.
EmptyCommonJs
No exports at all, and falling back to CommonJS semantics.
Value
A value that is made available as both the CommonJS exports and the ESM default export.
Unknown
Some error occurred while determining exports.
None
No exports, used by custom module types.
Implementations
Sourceimpl EcmascriptExports
impl EcmascriptExports
Sourcepub fn cell(self) -> Vc<Self>
pub fn cell(self) -> Vc<Self>
Places a value in a cell of the current task.
Cell is selected based on the value type and call order of cell.
Sourcepub fn resolved_cell(self) -> ResolvedVc<Self>
pub fn resolved_cell(self) -> ResolvedVc<Self>
Places a value in a cell of the current task. Returns a
ResolvedVc.
Cell is selected based on the value type and call order of cell.
Sourceimpl EcmascriptExports
impl EcmascriptExports
Sourcepub fn split_locals_and_reexports(self: Vc<Self>) -> Vc<bool>
pub fn split_locals_and_reexports(self: Vc<Self>) -> Vc<bool>
Returns whether this module should be split into separate locals and facade modules.
Splitting is enabled when the module has re-exports (star exports or imported bindings), which allows the tree-shaking optimization to separate local definitions from re-exports.