pub trait EcmascriptChunkItem:
ChunkItem
+ OutputAssetsReference
+ Send
+ Sync
+ NonLocalValue
+ ValueDebug {
// Required method
fn content_with_async_module_info<'life0, 'async_trait>(
&'life0 self,
async_module_info: Option<Vc<AsyncModuleInfo>>,
estimated: bool,
) -> Pin<Box<dyn Future<Output = Result<Vc<EcmascriptChunkItemContent>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Methods
Sourcefn content_with_async_module_info<'life0, 'async_trait>(
&'life0 self,
async_module_info: Option<Vc<AsyncModuleInfo>>,
estimated: bool,
) -> Pin<Box<dyn Future<Output = Result<Vc<EcmascriptChunkItemContent>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn content_with_async_module_info<'life0, 'async_trait>(
&'life0 self,
async_module_info: Option<Vc<AsyncModuleInfo>>,
estimated: bool,
) -> Pin<Box<dyn Future<Output = Result<Vc<EcmascriptChunkItemContent>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Fetches the content of the chunk item with async module info.
When estimated is true, it’s ok to provide an estimated content, since it’s only used for
compute the chunking. When estimated is true, this function should not invoke other
chunking operations that would cause cycles.