EcmascriptChunkItem

Trait EcmascriptChunkItem 

pub trait EcmascriptChunkItem:
    ChunkItem
    + OutputAssetsReference
    + Send
    + Sync
    + NonLocalValue
    + ValueDebug {
    // Required method
    fn content(self: Vc<Self>) -> Vc<EcmascriptChunkItemContent>
       where Self: Sized;

    // Provided method
    fn content_with_async_module_info(
        self: Vc<Self>,
        _async_module_info: Option<Vc<AsyncModuleInfo>>,
        _estimated: bool,
    ) -> Vc<EcmascriptChunkItemContent>
       where Self: Sized { ... }
}

Required Methods

fn content(self: Vc<Self>) -> Vc<EcmascriptChunkItemContent>
where Self: Sized,

Provided Methods

fn content_with_async_module_info( self: Vc<Self>, _async_module_info: Option<Vc<AsyncModuleInfo>>, _estimated: bool, ) -> Vc<EcmascriptChunkItemContent>
where Self: Sized,

Fetches the content of the chunk item with async module info. When estimated is true, it’s ok to provide an estimated content, since it’s only used for compute the chunking. When estimated is true, this function should not invoke other chunking operations that would cause cycles.